==> hivemq-extension-sdk-4.3.0-sources.jar: com/hivemq/extension/sdk/api/auth/parameter/PublishAuthorizerInput.java <==
/*
 * Copyright 2019 dc-square GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.hivemq.extension.sdk.api.auth.parameter;

import com.hivemq.extension.sdk.api.annotations.DoNotImplement;
import com.hivemq.extension.sdk.api.annotations.Immutable;
import com.hivemq.extension.sdk.api.annotations.NotNull;
import com.hivemq.extension.sdk.api.auth.PublishAuthorizer;
import com.hivemq.extension.sdk.api.packets.publish.PublishPacket;
import com.hivemq.extension.sdk.api.parameter.ClientBasedInput;

/**
 * This is the input parameter of any {@link PublishAuthorizer}
 * providing an unmodifiable inbound {@link PublishPacket} and {@link ClientBasedInput}.
 *
 * @author Christoph Schäbel
 * @author Florian Limpöck
 * @since 4.0.0
 */
@DoNotImplement
public interface PublishAuthorizerInput extends ClientBasedInput {

    /**
     * Get the unmodifiable publish packet that has to be authorized.
     *
     * @return The {@link PublishPacket} for this authorization call.
     * @since 4.0.0
     */
    @Immutable
    @NotNull PublishPacket getPublishPacket();
}

==> hivemq-extension-sdk-4.28.0-sources.jar: com/hivemq/extension/sdk/api/auth/parameter/PublishAuthorizerInput.java <==
/*
 * Copyright 2018-present HiveMQ GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hivemq.extension.sdk.api.auth.parameter;

import com.hivemq.extension.sdk.api.annotations.DoNotImplement;
import com.hivemq.extension.sdk.api.annotations.Immutable;
import com.hivemq.extension.sdk.api.annotations.NotNull;
import com.hivemq.extension.sdk.api.auth.PublishAuthorizer;
import com.hivemq.extension.sdk.api.packets.publish.PublishPacket;
import com.hivemq.extension.sdk.api.parameter.ClientBasedInput;

/**
 * This is the input parameter of any {@link PublishAuthorizer} providing an unmodifiable inbound {@link PublishPacket}
 * and {@link ClientBasedInput}.
 *
 * @author Christoph Schäbel
 * @author Florian Limpöck
 * @since 4.0.0, CE 2019.1
 */
@DoNotImplement
public interface PublishAuthorizerInput extends ClientBasedInput {

    /**
     * Get the unmodifiable publish packet that has to be authorized.
     *
     * @return The {@link PublishPacket} for this authorization call.
     * @since 4.0.0, CE 2019.1
     */
    @Immutable @NotNull PublishPacket getPublishPacket();
}
